==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AIntBaseTypeNoName.h <==
// public final class soot.jimple.parser.node.AIntBaseTypeNoName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8431aac78875928 soot_jimple_parser_node_AIntBaseTypeNoName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cf55e2dd32eddb45 soot_jimple_parser_node_PBaseTypeNoName

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseTypeNoName

#include "soot/jimple/parser/node/PBaseTypeNoName.h"

#ifndef _JC_soot_jimple_parser_node_AIntBaseTypeNoName_H_
#define _JC_soot_jimple_parser_node_AIntBaseTypeNoName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TInt$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$sub_refs	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$sub_nonrefs	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$refs	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$refs;
typedef struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$nonrefs	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$object;

typedef const struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$vmethods	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$vtable	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$vtable;
typedef const struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$vtype	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *);
extern void _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method$_init$2da21b9e71fc9816(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TInt$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AIntBaseTypeNoName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *);
extern struct _jc_soot_jimple_parser_node_TInt$object *_jc_soot_jimple_parser_node_AIntBaseTypeNoName$method$getInt$9989ca416f9368a2(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *);
extern void _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method$setInt$ecd6687e1107740d(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TInt$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AIntBaseTypeNoName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method_info$getInt$9989ca416f9368a2;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method_info$setInt$ecd6687e1107740d;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *);
	struct _jc_soot_jimple_parser_node_TInt$object	*(*getInt$9989ca416f9368a2)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setInt$ecd6687e1107740d)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TInt$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	soot_jimple_parser_node_PBaseTypeNoName;
	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$vmethods	soot_jimple_parser_node_AIntBaseTypeNoName;
};

// Vtype
struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$sub_refs {
	struct _jc_soot_jimple_parser_node_TInt$object	*__5fint__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$refs {
    _jc_soot_jimple_parser_node_AIntBaseTypeNoName$sub_refs	soot_jimple_parser_node_AIntBaseTypeNoName;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_AIntBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_AIntBaseTypeNoName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object {
	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$vtype	*vtype;
	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AIntBaseTypeNoName$vtype _jc_soot_jimple_parser_node_AIntBaseTypeNoName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AIntBaseTypeNoName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AIntBaseTypeNoName$class_object;

#endif	/* _JC_soot_jimple_parser_node_AIntBaseTypeNoName_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AIntBaseTypeNoName.h <==
// public final class soot.jimple.parser.node.AIntBaseTypeNoName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8431aac78875928 soot_jimple_parser_node_AIntBaseTypeNoName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cf55e2dd32eddb45 soot_jimple_parser_node_PBaseTypeNoName

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseTypeNoName

#include "soot/jimple/parser/node/PBaseTypeNoName.h"

#ifndef _JC_soot_jimple_parser_node_AIntBaseTypeNoName_H_
#define _JC_soot_jimple_parser_node_AIntBaseTypeNoName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TInt$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$sub_refs	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$sub_nonrefs	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$refs	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$refs;
typedef struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$nonrefs	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$object;

typedef const struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$vmethods	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$vtable	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$vtable;
typedef const struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$vtype	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method$_init$2da21b9e71fc9816(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TInt$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AIntBaseTypeNoName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TInt$object *_jc_soot_jimple_parser_node_AIntBaseTypeNoName$method$getInt$9989ca416f9368a2(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method$setInt$ecd6687e1107740d(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TInt$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AIntBaseTypeNoName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method_info$getInt$9989ca416f9368a2;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method_info$setInt$ecd6687e1107740d;
extern _jc_method _jc_soot_jimple_parser_node_AIntBaseTypeNoName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TInt$object	*(*getInt$9989ca416f9368a2)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setInt$ecd6687e1107740d)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TInt$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	soot_jimple_parser_node_PBaseTypeNoName;
	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$vmethods	soot_jimple_parser_node_AIntBaseTypeNoName;
};

// Vtype
struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$sub_refs {
	struct _jc_soot_jimple_parser_node_TInt$object	*__5fint__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$refs {
    _jc_soot_jimple_parser_node_AIntBaseTypeNoName$sub_refs	soot_jimple_parser_node_AIntBaseTypeNoName;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_AIntBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_AIntBaseTypeNoName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AIntBaseTypeNoName$object {
	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$vtype	*vtype;
	_jc_soot_jimple_parser_node_AIntBaseTypeNoName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AIntBaseTypeNoName$vtype _jc_soot_jimple_parser_node_AIntBaseTypeNoName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AIntBaseTypeNoName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AIntBaseTypeNoName$class_object;

#endif	/* _JC_soot_jimple_parser_node_AIntBaseTypeNoName_H_ */
